Class: OpenHAB::Core::Types::UnDefType
- Inherits:
-
Object
- Object
- OpenHAB::Core::Types::UnDefType
- Includes:
- State
- Defined in:
- lib/openhab/core/types/un_def_type.rb
Overview
There are situations when item states do not have any defined value. This might be because they have not been initialized yet (never received an state update so far) or because their state is ambiguous (e.g. a group item with members whose states do not match will be NULL).
Instance Method Summary collapse
-
#null? ⇒ true, false
Check if
self== NULL. -
#undef? ⇒ true, false
Check if
self== UNDEF.